@@ -10,7 +10,7 @@
 #include <string>
 #include <vector>
 #include <cmath>
-#include <cassert>
+#include "mystring.h"
 
 using namespace std;
 ///// string manupulation part
@@ -20,61 +20,6 @@ void removeAllCharsFromString(string &str, char c)
 	for ( ; str.find(c) != string::npos; str = str.replace(str.find(c), 1, "")) ;
 }
 
-char * strcpy(char *pDestination, const char *pSource)
-{
-	char *pSaveDest = pDestination;
-
-	for(; (*pDestination = *pSource) != 0; ++pSource, ++pDestination);
-	return pSaveDest;
-}
-
-char *strtok_r(char *s, const char *delim, char **last)
-{
-	char *spanp;
-	int c, sc;
-	char *tok;
-
-
-	if (s == NULL && (s = *last) == NULL)
-		return (NULL);
-
-	/*
-	 *    * Skip (span) leading delimiters (s += strspn(s, delim), sort of).
-	 *       */
-cont:
-	c = *s++;
-	for (spanp = (char *)delim; (sc = *spanp++) != 0;) {
-		if (c == sc)
-			goto cont;
-	}
-
-	if (c == 0) {           /* no non-delimiter characters */
-		*last = NULL;
-		return (NULL);
-	}
-	tok = s - 1;
-
-	/*
-	 *    * Scan token (scan for delimiters: s += strcspn(s, delim), sort of).
-	 *       * Note that delim must have one NUL; we stop if we see that, too.
-	 *          */
-	for (;;) {
-		c = *s++;
-		spanp = (char *)delim;
-		do {
-			if ((sc = *spanp++) == c) {
-				if (c == 0)
-					s = NULL;
-				else
-					s[-1] = 0;
-				*last = s;
-				return (tok);
-			}
-		} while (sc != 0);
-	}
-	/* NOTREACHED */
-}
-
 void replaceAll(string &str, char c1, char c2)
 {
 	char tmp[2] = {c2, 0};
@@ -97,6 +42,7 @@ void readAllProportions(const char *name)
 {
 }
 
+/*
 void readPvals(const char *signs_file_name, 
 		const char *pval_file_name, 
 		double *pvals, 
@@ -112,23 +58,23 @@ void readPvals(const char *signs_file_name,
 	char *save_ptr;
 	ltmp = fgets(line, 2000, f_p);
 	if (!ltmp)
-		assert(false);
+		Rprintf("goh khordi!!!\n");
 	ltmp = fgets(line, 2000, f_s);
 	if (!ltmp)
-		assert(false);
+		Rprintf("goh khordi!!!\n");
 
 	char *tmp;
-	strtok_r(line, ",", &save_ptr);
+	my_strtok_r(line, ",", &save_ptr);
 	int protein_it = 0;
 	while (1)
 	{
-		tmp = strtok_r(NULL, ",", &save_ptr);
+		tmp = my_strtok_r(NULL, ",", &save_ptr);
 		if (!tmp)
 			break;
 		string pr = tmp;
 		removeAllCharsFromString(pr, '\n');
 		removeAllCharsFromString(pr, '"');
-		strcpy(proteins[protein_it], pr.c_str());
+		my_strcpy(proteins[protein_it], pr.c_str());
 		protein_it++;
 	}
 
@@ -144,8 +90,8 @@ void readPvals(const char *signs_file_name,
 			break;
 
 		char *tmp;
-		tmp = strtok_r(line, ",\n\r", &save_ptr);
-		tmp = strtok_r(NULL, ",\n\r", &save_ptr);
+		tmp = my_strtok_r(line, ",\n\r", &save_ptr);
+		tmp = my_strtok_r(NULL, ",\n\r", &save_ptr);
 		double pvalue = strtod(tmp, NULL);
 		pvals[signs_row_num] = pvalue;
 
@@ -154,14 +100,14 @@ void readPvals(const char *signs_file_name,
 		if (!line[0])
 			break;
 
-		tmp = strtok_r(line, ",", &save_ptr);
+		tmp = my_strtok_r(line, ",", &save_ptr);
 		string name = tmp;
 		removeAllCharsFromString(name, '"');
-		strcpy(signs[signs_row_num], name.c_str());
+		my_strcpy(signs[signs_row_num], name.c_str());
 
 		while (1)
 		{
-			tmp = strtok_r(NULL, ",", &save_ptr);
+			tmp = my_strtok_r(NULL, ",", &save_ptr);
 			if (!tmp)
 				break;
 			string vl = tmp;
@@ -174,12 +120,12 @@ void readPvals(const char *signs_file_name,
 
 		signs_row_num++;
 		count++;
-		/*
-		fprintf(stderr, "%s\t%lf\n", tmp, pvalue);
-		if (count == 10)
-			return;
-		*/
+		
+		//Rprintf("%s\t%lf\n", tmp, pvalue);
+		//if (count == 10)
+		//	return;
 	}
 	fclose(f_p);
 	fclose(f_s);
 }
+*/
